## CELINE Core Ontology: Overview back to ToC

This ontology has the following classes and properties.

#### Classes

- Community Context
- Dataset Reference
- KPI Evaluation
- Scenario
- Simulation
- Simulation Run

#### Object Properties

- evaluates KPI
- has energy community
- has KPI evaluation
- has scenario
- has simulation
- has simulation run
- has time interval
- produces dataset
- uses asset
- uses dataset
- uses observation